pub struct RingInstanceBuffer<T: Pod> { /* private fields */ }Expand description
Ring buffer strategy for multi-buffered instance data.
Useful for triple-buffering or managing multiple frames in flight. Each frame gets its own slot in a circular buffer.
Implementations
Sourceimpl<T: Pod> RingInstanceBuffer<T>
impl<T: Pod> RingInstanceBuffer<T>
Sourcepub fn new(
device: &Device,
label_prefix: &str,
frame_count: usize,
capacity: usize,
) -> Self
pub fn new( device: &Device, label_prefix: &str, frame_count: usize, capacity: usize, ) -> Self
Create a new ring buffer with the specified number of frame slots.
Sourcepub fn current(&self) -> &InstanceBuffer<T>
pub fn current(&self) -> &InstanceBuffer<T>
Get the current frame’s buffer.
Sourcepub fn current_mut(&mut self) -> &mut InstanceBuffer<T>
pub fn current_mut(&mut self) -> &mut InstanceBuffer<T>
Get mutable reference to current frame’s buffer.
Sourcepub fn advance_frame(&mut self)
pub fn advance_frame(&mut self)
Advance to the next frame.
Sourcepub fn buffers(&self) -> &[InstanceBuffer<T>]
pub fn buffers(&self) -> &[InstanceBuffer<T>]
Get all buffers.
Sourcepub fn frame_index(&self) -> usize
pub fn frame_index(&self) -> usize
Get current frame index.