pub struct LayoutEngine { /* private fields */ }Expand description
Configurable layout engine.
Implementations
Sourceimpl LayoutEngine
impl LayoutEngine
Sourcepub fn new(mode: LayoutMode) -> Self
pub fn new(mode: LayoutMode) -> Self
Create a new layout engine with the specified mode.
Sourcepub fn set_mode(&mut self, mode: LayoutMode)
pub fn set_mode(&mut self, mode: LayoutMode)
Set the layout mode.
Sourcepub fn mode(&self) -> &LayoutMode
pub fn mode(&self) -> &LayoutMode
Get the current layout mode.
Sourcepub fn compute_layout(
&mut self,
tree: &UiTree,
viewport_size: Size<f32>,
widget_registry: &WidgetTypeRegistry,
)
pub fn compute_layout( &mut self, tree: &UiTree, viewport_size: Size<f32>, widget_registry: &WidgetTypeRegistry, )
Compute layout for the tree.
In synchronous mode, this blocks until layout is complete. In async mode, this queues a layout request and returns immediately.
Sourcepub fn poll_results(&mut self) -> usize
pub fn poll_results(&mut self) -> usize
Poll for async layout results.
Returns the number of results processed.
Sourcepub fn get_layout(&self, node_id: NodeId) -> Option<LayoutRect>
pub fn get_layout(&self, node_id: NodeId) -> Option<LayoutRect>
Get layout for a node.
In async mode, this may return a slightly stale layout.
Sourcepub fn is_layout_current(&self) -> bool
pub fn is_layout_current(&self) -> bool
Check if layout is current (not stale).
Sourcepub fn is_layout_in_progress(&self) -> bool
pub fn is_layout_in_progress(&self) -> bool
Check if async layout is in progress.
Sourcepub fn frames_stale(&self) -> u64
pub fn frames_stale(&self) -> u64
Get the number of frames layout is stale by.