pub struct VirtualScrollView<T> { /* private fields */ }Expand description
A virtual scroll view that manages item rendering.
Implementations
Sourceimpl<T> VirtualScrollView<T>
impl<T> VirtualScrollView<T>
Sourcepub fn new<F>(items: Vec<T>, item_height: f32, builder: F) -> Self
pub fn new<F>(items: Vec<T>, item_height: f32, builder: F) -> Self
Creates a new virtual scroll view with fixed height items.
Sourcepub fn with_variable_height<F>(
items: Vec<T>,
estimated_height: f32,
builder: F,
) -> Self
pub fn with_variable_height<F>( items: Vec<T>, estimated_height: f32, builder: F, ) -> Self
Creates a new virtual scroll view with variable height items.
Sourcepub fn with_config(self, config: VirtualScrollConfig) -> Self
pub fn with_config(self, config: VirtualScrollConfig) -> Self
Sets the configuration.
Sourcepub fn state(&self) -> &VirtualScrollState
pub fn state(&self) -> &VirtualScrollState
Gets the scroll state.
Sourcepub fn state_mut(&mut self) -> &mut VirtualScrollState
pub fn state_mut(&mut self) -> &mut VirtualScrollState
Gets mutable scroll state.
Sourcepub fn set_viewport_height(&mut self, height: f32)
pub fn set_viewport_height(&mut self, height: f32)
Sets the viewport height.
Sourcepub fn scroll_to_item(&mut self, index: usize)
pub fn scroll_to_item(&mut self, index: usize)
Scrolls to show a specific item.
Sourcepub fn update(&mut self, tree: &mut UiTree, dt: f32) -> VirtualScrollUpdate
pub fn update(&mut self, tree: &mut UiTree, dt: f32) -> VirtualScrollUpdate
Updates the scroll animation and visible items. Returns the nodes that were added or removed.